@@ -32,7 +32,7 @@ crew_controller_aws_batch <- function(
   seconds_interval = 0.5,
   seconds_timeout = 60,
   seconds_launch = 1800,
-  seconds_idle = Inf,
+  seconds_idle = 300,
   seconds_wall = Inf,
   retry_tasks = TRUE,
   tasks_max = Inf,
@@ -41,14 +41,17 @@ crew_controller_aws_batch <- function(
   reset_packages = FALSE,
   reset_options = FALSE,
   garbage_collection = FALSE,
-  launch_max = 5L,
+  crashes_error = 5L,
   processes = NULL,
-  aws_batch_config = list(),
-  aws_batch_credentials = list(),
+  r_arguments = c("--no-save", "--no-restore"),
+  options_metrics = crew::crew_options_metrics(),
+  options_aws_batch = crew.aws.batch::crew_options_aws_batch(),
+  aws_batch_config = NULL,
+  aws_batch_credentials = NULL,
   aws_batch_endpoint = NULL,
   aws_batch_region = NULL,
-  aws_batch_job_definition,
-  aws_batch_job_queue,
+  aws_batch_job_definition = NULL,
+  aws_batch_job_queue = NULL,
   aws_batch_share_identifier = NULL,
   aws_batch_scheduling_priority_override = NULL,
   aws_batch_parameters = NULL,
@@ -85,9 +88,12 @@ crew_controller_aws_batch <- function(
     reset_packages = reset_packages,
     reset_options = reset_options,
     garbage_collection = garbage_collection,
-    launch_max = launch_max,
+    crashes_error = crashes_error,
     tls = tls,
     processes = processes,
+    r_arguments = r_arguments,
+    options_metrics = options_metrics,
+    options_aws_batch = options_aws_batch,
     aws_batch_config = aws_batch_config,
     aws_batch_credentials = aws_batch_credentials,
     aws_batch_endpoint = aws_batch_endpoint,
